@@ -2,20 +2,21 @@
 # -*- coding: utf-8 -*-
 
 import sys
-import csv
 from . import _chp_csv_path, _db_path
 from .util import Directory
 
 def build(chp_csv_path=None, db_path=None):
 
+    # use default path if either path is not given.
+
     if chp_csv_path is None:
         chp_csv_path = _chp_csv_path
-
     if db_path is None:
         db_path = _db_path
 
-    dir_ = Directory(db_path)
+    # build the index
 
+    dir_ = Directory(db_path)
     with open(chp_csv_path) as csv_f:
         dir_.load_chp_csv(csv_f)
 
@@ -35,6 +36,7 @@ if __name__ == '__main__':
 
     try:
         import clime
-        clime.start(white_pattern=clime.CMD_SUFFIX)
     except ImportError:
         build(*sys.argv[1:])
+    else:
+        clime.start(white_pattern=clime.CMD_SUFFIX)
