@@ -14,7 +14,7 @@ class Address(object):
             (?P<name>.+?)
         )
         (?:
-            (?P<unit>[縣市鄉鎮市區村里路段街巷弄號樓])
+            (?P<unit>[縣市鄉鎮市區村里鄰路段街巷弄號樓])
             |
             (?=\d+(?:[之-]\d+)?[巷弄號樓]|$)
         )
@@ -75,9 +75,28 @@ class Address(object):
 
         return s
 
+    TO_INGORE = set(u'鄰里')
+
     @staticmethod
     def tokenize(addr_str):
-        return tuple(Address.TOKEN_RE.findall(Address.normalize(addr_str)))
+
+        tokens = Address.TOKEN_RE.findall(Address.normalize(addr_str))
+
+        # remove tokens whose unit is in TO_INGORE
+
+        len_tokens = len(tokens)
+
+        i = 2
+        while i < len_tokens:
+            name = tokens[i][Address.NAME]
+            unit = tokens[i][Address.UNIT]
+            if unit and unit in Address.TO_INGORE and name != u'宮后':
+                del tokens[i]
+                len_tokens -= 1
+            else:
+                i += 1
+
+        return tuple(tokens)
 
     def __init__(self, addr_str):
         self.tokens = Address.tokenize(addr_str)
